"use strict";

exports.__esModule = true;
exports.CListIcon = exports.CListItem = exports.CUnorderedList = exports.COrderedList = exports.CList = void 0;

var _cIcon = require("@chakra-ui/c-icon");

var _vueSystem = require("@chakra-ui/vue-system");

var _vue = require("vue");

var _vueUtils = require("@chakra-ui/vue-utils");

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * List is used to display list items, it renders a `<ul>` by default.
 *
 * @see Docs https://vue.chakra-ui.com/docs/data-display/list
 */
var CList = (0, _vue.defineComponent)({
  props: {
    as: {
      type: [Object, String],
      "default": 'ul'
    },
    styleType: {
      type: _vueUtils.SAO,
      "default": 'none'
    },
    stylePosition: _vueUtils.SAO,
    spacing: _vueUtils.SNAO
  },
  setup: function setup(props, _ref) {
    var slots = _ref.slots,
        attrs = _ref.attrs;
    var styles = (0, _vueSystem.useMultiStyleConfig)('List', props);
    (0, _vueSystem.StylesProvider)(styles);
    var selector = '& > *:not(style) ~ *:not(style)';
    var spacingStyle = (0, _vue.computed)(function () {
      var _ref2;

      return props.spacing ? (_ref2 = {}, _ref2[selector] = {
        mt: props.spacing
      }, _ref2) : {};
    });
    return function () {
      var validChildren = (0, _vueUtils.getValidChildren)(slots);
      return (0, _vue.h)((0, _vueSystem.chakra)(props.as, _extends({
        label: 'list',
        listStyleType: props.styleType,
        listStylePosition: props.stylePosition,
        role: 'list',
        __css: _extends({}, styles.value.container, spacingStyle.value)
      }, attrs)), {}, function () {
        return validChildren;
      });
    };
  }
});
exports.CList = CList;
var COrderedList = (0, _vue.defineComponent)({
  props: {},
  setup: function setup(props, _ref3) {
    var slots = _ref3.slots,
        attrs = _ref3.attrs;
    return function () {
      return (0, _vue.h)(CList, _extends({
        styleType: 'decimal',
        marginStart: '1em'
      }, attrs), slots);
    };
  }
});
exports.COrderedList = COrderedList;
var CUnorderedList = (0, _vue.defineComponent)({
  props: {},
  setup: function setup(props, _ref4) {
    var slots = _ref4.slots,
        attrs = _ref4.attrs;
    return function () {
      return (0, _vue.h)(CList, _extends({
        styleType: 'initial',
        marginStart: '1em'
      }, attrs), slots);
    };
  }
});
exports.CUnorderedList = CUnorderedList;
var CListItem = (0, _vue.defineComponent)({
  props: {},
  setup: function setup(props, _ref5) {
    var slots = _ref5.slots,
        attrs = _ref5.attrs;
    var styles = (0, _vueSystem.useStyles)();
    return function () {
      return (0, _vue.h)((0, _vueSystem.chakra)('li', {
        label: 'list__item',
        __css: _extends({}, styles.value.item)
      }), _extends({}, attrs), slots);
    };
  }
});
exports.CListItem = CListItem;
var CListIcon = (0, _vue.defineComponent)({
  props: {},
  setup: function setup(props, _ref6) {
    var slots = _ref6.slots,
        attrs = _ref6.attrs;
    var styles = (0, _vueSystem.useStyles)();
    return function () {
      return (0, _vue.h)(_cIcon.CIcon, _extends({
        role: 'presentation'
      }, attrs, {
        __css: _extends({}, styles.value.icon)
      }), slots);
    };
  }
});
exports.CListIcon = CListIcon;
//# sourceMappingURL=list.js.map