"use strict";

exports.__esModule = true;
exports.CSimpleGrid = void 0;

var _vue = require("vue");

var _vueUtils = require("@chakra-ui/vue-utils");

var _grid = require("./grid");

var _utils = require("@chakra-ui/utils");

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * SimpleGrid
 *
 * Vue component make that providers a simpler interface, and
 * make its easy to create responsive grid layouts.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/simple-grid
 */
var CSimpleGrid = (0, _vue.defineComponent)({
  props: {
    as: {
      type: [Object, String],
      "default": 'ul'
    },
    minChildWidth: _vueUtils.SNAO,
    columns: _vueUtils.SNAO,
    spacing: _vueUtils.SNAO,
    spacingX: _vueUtils.SNAO,
    spacingY: _vueUtils.SNAO
  },
  setup: function setup(props, _ref) {
    var slots = _ref.slots,
        attrs = _ref.attrs;
    var templateColumns = (0, _vue.computed)(function () {
      return props.minChildWidth ? widthToColumns(props.minChildWidth) : countToColumns(props.columns);
    });
    return function () {
      return (0, _vue.h)(_grid.CGrid, _extends({
        label: 'simple-grid',
        gap: props.spacing,
        columnGap: props.spacingX,
        rowGap: props.spacingY,
        templateColumns: templateColumns.value
      }, attrs), slots);
    };
  }
});
exports.CSimpleGrid = CSimpleGrid;

function toPx(n) {
  return (0, _utils.isNumber)(n) ? n + "px" : n;
}

function widthToColumns(width) {
  return (0, _utils.mapResponsive)(width, function (value) {
    return (0, _utils.isNull)(value) ? null : "repeat(auto-fit, minmax(" + toPx(value) + ", 1fr))";
  });
}

function countToColumns(count) {
  return (0, _utils.mapResponsive)(count, function (value) {
    return (0, _utils.isNull)(value) ? null : "repeat(" + value + ", minmax(0, 1fr))";
  });
}
//# sourceMappingURL=simple-grid.js.map