"use strict";

exports.__esModule = true;
exports.CVStack = exports.CHStack = exports.CStack = exports.CStackItem = exports.CStackDivider = void 0;

var _vue = require("vue");

var _vueSystem = require("@chakra-ui/vue-system");

var _stack = require("./stack.utils");

var _vueUtils = require("@chakra-ui/vue-utils");

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var CStackDivider = (0, _vue.defineComponent)({
  setup: function setup(_, _ref) {
    var attrs = _ref.attrs;
    return function () {
      return (0, _vue.h)((0, _vueSystem.chakra)('div', {
        label: 'stack__divider',
        borderWidth: 0,
        alignSelf: 'stretch',
        borderColor: 'inherit',
        width: 'auto',
        height: 'auto',
        __css: attrs.__css
      }));
    };
  }
});
exports.CStackDivider = CStackDivider;
var CStackItem = (0, _vue.defineComponent)({
  setup: function setup(_, _ref2) {
    var attrs = _ref2.attrs;
    return function () {
      return (0, _vue.h)((0, _vueSystem.chakra)('div', _extends({
        label: 'stack__item'
      }, attrs, {
        display: 'inline-block',
        flex: '0 0 auto',
        minWidth: 0,
        __css: attrs.__css
      })));
    };
  }
});
exports.CStackItem = CStackItem;
var stackProps = {
  as: {
    type: [Object, String],
    "default": 'div'
  },
  align: _vueUtils.SAO,
  justify: _vueUtils.SAO,
  wrap: _vueUtils.SAO,
  spacing: {
    type: _vueUtils.SNAO,
    "default": '0.5rem'
  },
  direction: _vueUtils.SAO,
  // todo: divider
  divider: [Object, Boolean],
  shouldWrapChildren: [Boolean],
  isInline: [Boolean]
};
/**
 * Stacks help you easily create flexible and automatically distributed layouts
 *
 * You can stack elements in the horizontal or vertical direction,
 * and apply a space or/and divider between each element.
 *
 * It uses `display: flex` internally and renders a `div`.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/stack
 *
 */

var CStack = (0, _vue.defineComponent)({
  name: 'CStack',
  props: stackProps,
  setup: function setup(props, _ref3) {
    var slots = _ref3.slots,
        attrs = _ref3.attrs;
    var direction = (0, _vue.computed)(function () {
      var _props$direction;

      return props.isInline ? 'row' : (_props$direction = props.direction) != null ? _props$direction : 'column';
    });
    var styles = (0, _vue.computed)(function () {
      return (0, _stack.getStackStyles)({
        direction: direction.value,
        spacing: props.spacing
      });
    });
    var dividerStyle = (0, _vue.computed)(function () {
      return (0, _stack.getDividerStyles)({
        spacing: props.spacing,
        direction: direction.value
      });
    });
    var hasDivider = (0, _vue.computed)(function () {
      return !!props.divider;
    });
    var shouldUseChildren = (0, _vue.computed)(function () {
      return !props.shouldWrapChildren && !hasDivider.value;
    });
    return function () {
      var _ref4;

      var validChildren = (0, _vueUtils.getValidChildren)(slots);
      var clones = shouldUseChildren.value ? validChildren : validChildren.map(function (child, index) {
        var isLast = index + 1 === validChildren.length;
        var wrappedChild = (0, _vue.createVNode)(CStackItem, {
          key: index
        }, child);

        var _child = props.shouldWrapChildren ? wrappedChild : child;

        if (!hasDivider.value) return _child; // todo: temporary divider

        var clonedDivider = (0, _vue.createVNode)(CStackDivider, {
          borderColor: 'blue.200',
          __css: dividerStyle.value
        });

        var _divider = isLast ? null : clonedDivider;

        return (0, _vue.createVNode)(_vue.Fragment, {
          key: index
        }, [_child, _divider]);
      });
      return (0, _vue.h)((0, _vueSystem.chakra)('div', {
        label: attrs.label ? attrs.label : 'stack',
        // CHStack and CVStack
        display: 'flex',
        alignItems: props.align,
        justifyContent: props.justify,
        flexDirection: styles.value.flexDirection,
        flexWrap: props.wrap,
        __css: hasDivider.value ? {} : (_ref4 = {}, _ref4[_stack.selector] = styles.value[_stack.selector], _ref4)
      }), function () {
        return clones;
      });
    };
  }
});
/**
 * A view that arranges its children in a horizontal line.
 */

exports.CStack = CStack;
var CHStack = (0, _vue.defineComponent)({
  name: 'CHStack',
  props: stackProps,
  setup: function setup(props, _ref5) {
    var attrs = _ref5.attrs,
        slots = _ref5.slots;
    return function () {
      return (0, _vue.h)(CStack, _extends({
        label: 'stack-horizontal',
        align: 'center'
      }, props, attrs, {
        direction: 'row'
      }), slots);
    };
  }
});
/**
 * A view that arranges its children in a vertical line.
 */

exports.CHStack = CHStack;
var CVStack = (0, _vue.defineComponent)({
  name: 'CVStack',
  props: stackProps,
  setup: function setup(props, _ref6) {
    var attrs = _ref6.attrs,
        slots = _ref6.slots;
    return function () {
      return (0, _vue.h)(CStack, _extends({
        label: 'stack-vertical',
        align: 'center'
      }, props, attrs, {
        direction: 'column'
      }), slots);
    };
  }
});
exports.CVStack = CVStack;
//# sourceMappingURL=stack.js.map