function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { h, defineComponent, computed } from 'vue';
import { chakra } from '@chakra-ui/vue-system';
import { filterUndefined, mapResponsive } from '@chakra-ui/utils';
import { SNAO } from '@chakra-ui/vue-utils';

/**
 * Vue component used to create grid layouts.
 *
 * It renders a `div` with `display: grid` and
 * comes with helpful style shorthand.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/grid
 */
export var CGrid = defineComponent({
  props: {
    as: {
      type: [String, Object],
      default: 'div'
    },
    templateColumns: SNAO,
    gap: SNAO,
    rowGap: SNAO,
    columnGap: SNAO,
    autoFlow: SNAO,
    autoRows: SNAO,
    autoColumns: SNAO,
    templateRows: SNAO,
    templateAreas: SNAO,
    area: SNAO,
    column: SNAO,
    row: SNAO
  },

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    var styles = computed(() => filterUndefined({
      display: 'grid',
      gridArea: props.area,
      gridTemplateAreas: props.templateAreas,
      gridGap: props.gap,
      gridRowGap: props.rowGap,
      gridColumnGap: props.columnGap,
      gridAutoColumns: props.autoColumns,
      gridColumn: props.column,
      gridRow: props.row,
      gridAutoFlow: props.autoFlow,
      gridAutoRows: props.autoRows,
      gridTemplateRows: props.templateRows,
      gridTemplateColumns: props.templateColumns
    }));
    return () => {
      return h(chakra(props.as, _extends({
        label: 'grid',
        __css: styles.value
      }, attrs)), {}, slots);
    };
  }

});

function spanFn(span) {
  return mapResponsive(span, value => value === 'auto' ? 'auto' : "span " + value + "/span " + value);
}

export var CGridItem = defineComponent({
  props: {
    as: {
      type: [String, Object],
      default: 'div'
    },
    colSpan: SNAO,
    colStart: SNAO,
    colEnd: SNAO,
    rowStart: SNAO,
    rowEnd: SNAO,
    rowSpan: SNAO
  },

  setup(props, _ref2) {
    var {
      slots,
      attrs
    } = _ref2;
    var styles = computed(() => filterUndefined({
      gridColumn: spanFn(props.colSpan),
      gridRow: spanFn(props.rowSpan),
      gridColumnStart: props.colStart,
      gridColumnEnd: props.colEnd,
      gridRowStart: props.rowStart,
      gridRowEnd: props.rowEnd
    }));
    return () => {
      return h(chakra(props.as, {
        label: 'grid__item',
        __css: styles.value
      }), attrs, slots);
    };
  }

});
//# sourceMappingURL=grid.js.map