function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { h, defineComponent, computed } from 'vue';
import { SNAO } from '@chakra-ui/vue-utils';
import { CGrid } from './grid';
import { isNull, isNumber, mapResponsive } from '@chakra-ui/utils';

/**
 * SimpleGrid
 *
 * Vue component make that providers a simpler interface, and
 * make its easy to create responsive grid layouts.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/simple-grid
 */
export var CSimpleGrid = defineComponent({
  props: {
    as: {
      type: [Object, String],
      default: 'ul'
    },
    minChildWidth: SNAO,
    columns: SNAO,
    spacing: SNAO,
    spacingX: SNAO,
    spacingY: SNAO
  },

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    var templateColumns = computed(() => props.minChildWidth ? widthToColumns(props.minChildWidth) : countToColumns(props.columns));
    return () => {
      return h(CGrid, _extends({
        label: 'simple-grid',
        gap: props.spacing,
        columnGap: props.spacingX,
        rowGap: props.spacingY,
        templateColumns: templateColumns.value
      }, attrs), slots);
    };
  }

});

function toPx(n) {
  return isNumber(n) ? n + "px" : n;
}

function widthToColumns(width) {
  return mapResponsive(width, value => isNull(value) ? null : "repeat(auto-fit, minmax(" + toPx(value) + ", 1fr))");
}

function countToColumns(count) {
  return mapResponsive(count, value => isNull(value) ? null : "repeat(" + value + ", minmax(0, 1fr))");
}
//# sourceMappingURL=simple-grid.js.map