import { chakra } from '@chakra-ui/vue-system';
import { defineComponent, h } from '@vue/runtime-core';

/**
 * A flexible flex spacer that expands along the major axis of its containing flex layout.
 * It renders a `div` by default, and takes up any available space.
 *
 * @see Docs https://chakra-ui.com/docs/layout/flex#using-the-spacer
 */
export var CSpacer = defineComponent({
  setup(_, _ref) {
    var {
      slots
    } = _ref;
    return () => {
      return h(chakra('div', {
        label: 'spacer',
        baseStyle: {
          flex: 1,
          justifySelf: 'stretch',
          alignSelf: 'stretch'
        }
      }), {}, slots);
    };
  }

});
//# sourceMappingURL=spacer.js.map