import { BoxProps } from './box';
import { PropType, Component, ConcreteComponent } from 'vue';
import { HTMLChakraProps, SystemProps, ResponsiveValue } from '@chakra-ui/vue-system';
export interface GridProps extends HTMLChakraProps<'div'>, GridOptions {
}
export interface GridOptions {
    /**
     * Short hand prop for `gridTemplateColumns`
     * @type SystemProps["gridTemplateColumns"]
     */
    templateColumns?: SystemProps['gridTemplateColumns'];
    /**
     * Short hand prop for `gridGap`
     * @type SystemProps["gridGap"]
     */
    gap?: SystemProps['gridGap'];
    /**
     * Short hand prop for `gridRowGap`
     * @type SystemProps["gridRowGap"]
     */
    rowGap?: SystemProps['gridRowGap'];
    /**
     * Short hand prop for `gridColumnGap`
     * @type SystemProps["gridColumnGap"]
     */
    columnGap?: SystemProps['gridColumnGap'];
    /**
     * Short hand prop for `gridAutoFlow`
     * @type SystemProps["gridAutoFlow"]
     */
    autoFlow?: SystemProps['gridAutoFlow'];
    /**
     * Short hand prop for `gridAutoRows`
     * @type SystemProps["gridAutoRows"]
     */
    autoRows?: SystemProps['gridAutoRows'];
    /**
     * Short hand prop for `gridAutoColumns`
     * @type SystemProps["gridAutoColumns"]
     */
    autoColumns?: SystemProps['gridAutoColumns'];
    /**
     * Short hand prop for `gridTemplateRows`
     * @type SystemProps["gridTemplateRows"]
     */
    templateRows?: SystemProps['gridTemplateRows'];
    /**
     * Short hand prop for `gridTemplateAreas`
     * @type SystemProps["gridTemplateAreas"]
     */
    templateAreas?: SystemProps['gridTemplateAreas'];
    /**
     * Short hand prop for `gridArea`
     * @type SystemProps["gridArea"]
     */
    area?: SystemProps['gridArea'];
    /**
     * Short hand prop for `gridColumn`
     * @type SystemProps["gridColumn"]
     */
    column?: SystemProps['gridColumn'];
    /**
     * Short hand prop for `gridRow`
     * @type SystemProps["gridRow"]
     */
    row?: SystemProps['gridRow'];
}
export interface GridItemProps extends BoxProps {
    /**
     * The number of columns the grid item should `span`.
     * @type ResponsiveValue<number | "auto">
     */
    colSpan?: ResponsiveValue<number | 'auto'>;
    /**
     * The column number the grid item should start.
     * @type ResponsiveValue<number | "auto">
     */
    colStart?: ResponsiveValue<number | 'auto'>;
    /**
     * @type ResponsiveValue<number | "auto">
     */
    colEnd?: ResponsiveValue<number | 'auto'>;
    /**
     * @type ResponsiveValue<number | "auto">
     */
    rowStart?: ResponsiveValue<number | 'auto'>;
    /**
     * @type ResponsiveValue<number | "auto">
     */
    rowEnd?: ResponsiveValue<number | 'auto'>;
    /**
     * @type ResponsiveValue<number | "auto">
     */
    rowSpan?: ResponsiveValue<number | 'auto'>;
}
/**
 * Vue component used to create grid layouts.
 *
 * It renders a `div` with `display: grid` and
 * comes with helpful style shorthand.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/grid
 */
export declare const CGrid: import("vue").DefineComponent<{
    as: {
        type: PropType<string | Component<any, any, any, import("vue").ComputedOptions, import("vue").MethodOptions> | ConcreteComponent<{}, any, any, import("vue").ComputedOptions, import("vue").MethodOptions>>;
        default: string;
    };
    templateColumns: PropType<ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "none" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max-content" | "min-content" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl" | "subgrid">> | undefined>;
    gap: PropType<ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined>;
    rowGap: PropType<ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined>;
    columnGap: PropType<ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined>;
    autoFlow: PropType<ResponsiveValue<import("csstype").Property.GridAutoFlow> | undefined>;
    autoRows: PropType<ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max-content" | "min-content" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined>;
    autoColumns: PropType<ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max-content" | "min-content" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined>;
    templateRows: PropType<ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "none" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max-content" | "min-content" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl" | "subgrid">> | undefined>;
    templateAreas: PropType<ResponsiveValue<import("csstype").Property.GridTemplateAreas> | undefined>;
    area: PropType<ResponsiveValue<import("csstype").Property.GridArea> | undefined>;
    column: PropType<ResponsiveValue<import("csstype").Property.GridColumn> | undefined>;
    row: PropType<ResponsiveValue<import("csstype").Property.GridRow> | undefined>;
}, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    as: string | Component<any, any, any, import("vue").ComputedOptions, import("vue").MethodOptions> | ConcreteComponent<{}, any, any, import("vue").ComputedOptions, import("vue").MethodOptions>;
} & {
    area?: ResponsiveValue<import("csstype").Property.GridArea> | undefined;
    columnGap?: ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined;
    rowGap?: ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined;
    gap?: ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined;
    column?: ResponsiveValue<import("csstype").Property.GridColumn> | undefined;
    row?: ResponsiveValue<import("csstype").Property.GridRow> | undefined;
    templateColumns?: ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "none" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max-content" | "min-content" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl" | "subgrid">> | undefined;
    autoFlow?: ResponsiveValue<import("csstype").Property.GridAutoFlow> | undefined;
    autoRows?: ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max-content" | "min-content" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined;
    autoColumns?: ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max-content" | "min-content" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined;
    templateRows?: ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "none" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max-content" | "min-content" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl" | "subgrid">> | undefined;
    templateAreas?: ResponsiveValue<import("csstype").Property.GridTemplateAreas> | undefined;
}>, {
    as: string | Component<any, any, any, import("vue").ComputedOptions, import("vue").MethodOptions> | ConcreteComponent<{}, any, any, import("vue").ComputedOptions, import("vue").MethodOptions>;
}>;
export declare const CGridItem: import("vue").DefineComponent<{
    as: {
        type: PropType<string | Component<any, any, any, import("vue").ComputedOptions, import("vue").MethodOptions> | ConcreteComponent<{}, any, any, import("vue").ComputedOptions, import("vue").MethodOptions>>;
        default: string;
    };
    colSpan: PropType<ResponsiveValue<number | "auto"> | undefined>;
    colStart: PropType<ResponsiveValue<number | "auto"> | undefined>;
    colEnd: PropType<ResponsiveValue<number | "auto"> | undefined>;
    rowStart: PropType<ResponsiveValue<number | "auto"> | undefined>;
    rowEnd: PropType<ResponsiveValue<number | "auto"> | undefined>;
    rowSpan: PropType<ResponsiveValue<number | "auto"> | undefined>;
}, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    as: string | Component<any, any, any, import("vue").ComputedOptions, import("vue").MethodOptions> | ConcreteComponent<{}, any, any, import("vue").ComputedOptions, import("vue").MethodOptions>;
} & {
    colSpan?: ResponsiveValue<number | "auto"> | undefined;
    colStart?: ResponsiveValue<number | "auto"> | undefined;
    colEnd?: ResponsiveValue<number | "auto"> | undefined;
    rowStart?: ResponsiveValue<number | "auto"> | undefined;
    rowEnd?: ResponsiveValue<number | "auto"> | undefined;
    rowSpan?: ResponsiveValue<number | "auto"> | undefined;
}>, {
    as: string | Component<any, any, any, import("vue").ComputedOptions, import("vue").MethodOptions> | ConcreteComponent<{}, any, any, import("vue").ComputedOptions, import("vue").MethodOptions>;
}>;
