import { ResponsiveValue } from '@chakra-ui/vue-system';
import { PropType } from 'vue';
import { GridProps } from './grid';
interface SimpleGridOptions {
    /**
     * The width at which child elements will break into columns. Pass a number for pixel values or a string for any other valid CSS length.
     */
    minChildWidth?: GridProps['minWidth'];
    /**
     * The number of columns
     */
    columns?: ResponsiveValue<number>;
    /**
     * The gap between the grid items
     */
    spacing?: GridProps['gridGap'];
    /**
     * The column gap between the grid items
     */
    spacingX?: GridProps['gridGap'];
    /**
     * The row gap between the grid items
     */
    spacingY?: GridProps['gridGap'];
}
export interface SimpleGridProps extends GridProps, SimpleGridOptions {
}
/**
 * SimpleGrid
 *
 * Vue component make that providers a simpler interface, and
 * make its easy to create responsive grid layouts.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/simple-grid
 */
export declare const CSimpleGrid: import("vue").DefineComponent<{
    as: {
        type: PropType<"a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect">;
        default: string;
    };
    minChildWidth: PropType<ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "-moz-max-content" | "-moz-min-content" | "fit-content" | "max-content" | "min-content" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl" | "-moz-fit-content" | "-webkit-fit-content" | "-webkit-max-content" | "intrinsic" | "min-intrinsic" | "-webkit-fill-available" | "-webkit-min-content">> | undefined>;
    columns: PropType<ResponsiveValue<number> | undefined>;
    spacing: PropType<ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined>;
    spacingX: PropType<ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined>;
    spacingY: PropType<ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined>;
}, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    as: "a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect";
} & {
    columns?: ResponsiveValue<number> | undefined;
    spacing?: ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined;
    minChildWidth?: ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "-moz-max-content" | "-moz-min-content" | "fit-content" | "max-content" | "min-content" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl" | "-moz-fit-content" | "-webkit-fit-content" | "-webkit-max-content" | "intrinsic" | "min-intrinsic" | "-webkit-fill-available" | "-webkit-min-content">> | undefined;
    spacingX?: ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined;
    spacingY?: ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "sm" | "md" | "lg" | "xl" | "2xl" | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9" | "10" | "12" | "14" | "16" | "20" | "24" | "28" | "32" | "36" | "40" | "44" | "48" | "52" | "56" | "60" | "64" | "72" | "80" | "96" | "0.5" | "1.5" | "2.5" | "3.5" | "xs" | "3xl" | "4xl" | "5xl" | "6xl" | "7xl" | "8xl" | "max" | "min" | "full" | "3xs" | "2xs" | "container.sm" | "container.md" | "container.lg" | "container.xl">> | undefined;
}>, {
    as: "a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect";
}>;
export {};
