import { SystemProps } from '@chakra-ui/styled-system';
import { PropType, Component } from 'vue';
import { HTMLChakraProps } from '@chakra-ui/vue-system';
import { StackDirection } from './stack.utils';
interface StackOptions {
    /**
     * Shorthand for `alignItems` style prop
     * @type SystemStyleObject["alignItems"]
     */
    align?: SystemProps['alignItems'];
    /**
     * Shorthand for `justifyContent` style prop
     * @type SystemStyleObject["justifyContent"]
     */
    justify?: SystemProps['justifyContent'];
    /**
     * Shorthand for `flexWrap` style prop
     * @type SystemStyleObject["flexWrap"]
     */
    wrap?: SystemProps['flexWrap'];
    /**
     * The space between each stack item
     * @type SystemStyleObject["margin"]
     */
    spacing?: SystemProps['margin'];
    /**
     * The direction to stack the items.
     */
    direction?: StackDirection;
    /**
     * If `true`, each stack item will show a divider
     * @type Component | boolean
     */
    divider?: Component | boolean;
    /**
     * If `true`, the children will be wrapped in a `Box` with
     * `display: inline-block`, and the `Box` will take the spacing props
     */
    shouldWrapChildren?: boolean;
    /**
     * If `true` the items will be stacked horizontally.
     */
    isInline?: boolean;
}
export interface StackDividerProps extends HTMLChakraProps<'div'> {
}
export declare const CStackDivider: import("vue").DefineComponent<{}, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, import("vue").EmitsOptions, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{} & {}>, {}>;
export declare const CStackItem: import("vue").DefineComponent<{}, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, import("vue").EmitsOptions, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{} & {}>, {}>;
export interface StackProps extends HTMLChakraProps<'div'>, StackOptions {
}
/**
 * Stacks help you easily create flexible and automatically distributed layouts
 *
 * You can stack elements in the horizontal or vertical direction,
 * and apply a space or/and divider between each element.
 *
 * It uses `display: flex` internally and renders a `div`.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/stack
 *
 */
export declare const CStack: import("vue").DefineComponent<{
    as: {
        type: PropType<"a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect">;
        default: string;
    };
    align: PropType<import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.AlignItems> | undefined>;
    justify: PropType<import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.JustifyContent> | undefined>;
    wrap: PropType<import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.FlexWrap> | undefined>;
    spacing: {
        type: PropType<import("@chakra-ui/styled-system").ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5">> | undefined>;
        default: string;
    };
    direction: PropType<StackDirection | undefined>;
    divider: PropType<boolean | Component<any, any, any, import("vue").ComputedOptions, import("vue").MethodOptions> | undefined>;
    shouldWrapChildren: PropType<boolean | undefined>;
    isInline: PropType<boolean | undefined>;
}, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    as: "a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect";
    spacing: import("@chakra-ui/styled-system").ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5">> | undefined;
} & {
    direction?: StackDirection | undefined;
    justify?: import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.JustifyContent> | undefined;
    wrap?: import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.FlexWrap> | undefined;
    divider?: boolean | Component<any, any, any, import("vue").ComputedOptions, import("vue").MethodOptions> | undefined;
    align?: import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.AlignItems> | undefined;
    shouldWrapChildren?: boolean | undefined;
    isInline?: boolean | undefined;
}>, {
    as: "a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect";
    spacing: import("@chakra-ui/styled-system").ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5">> | undefined;
}>;
/**
 * A view that arranges its children in a horizontal line.
 */
export declare const CHStack: import("vue").DefineComponent<{
    as: {
        type: PropType<"a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect">;
        default: string;
    };
    align: PropType<import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.AlignItems> | undefined>;
    justify: PropType<import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.JustifyContent> | undefined>;
    wrap: PropType<import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.FlexWrap> | undefined>;
    spacing: {
        type: PropType<import("@chakra-ui/styled-system").ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5">> | undefined>;
        default: string;
    };
    direction: PropType<StackDirection | undefined>;
    divider: PropType<boolean | Component<any, any, any, import("vue").ComputedOptions, import("vue").MethodOptions> | undefined>;
    shouldWrapChildren: PropType<boolean | undefined>;
    isInline: PropType<boolean | undefined>;
}, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    as: "a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect";
    spacing: import("@chakra-ui/styled-system").ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5">> | undefined;
} & {
    direction?: StackDirection | undefined;
    justify?: import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.JustifyContent> | undefined;
    wrap?: import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.FlexWrap> | undefined;
    divider?: boolean | Component<any, any, any, import("vue").ComputedOptions, import("vue").MethodOptions> | undefined;
    align?: import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.AlignItems> | undefined;
    shouldWrapChildren?: boolean | undefined;
    isInline?: boolean | undefined;
}>, {
    as: "a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect";
    spacing: import("@chakra-ui/styled-system").ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5">> | undefined;
}>;
/**
 * A view that arranges its children in a vertical line.
 */
export declare const CVStack: import("vue").DefineComponent<{
    as: {
        type: PropType<"a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect">;
        default: string;
    };
    align: PropType<import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.AlignItems> | undefined>;
    justify: PropType<import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.JustifyContent> | undefined>;
    wrap: PropType<import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.FlexWrap> | undefined>;
    spacing: {
        type: PropType<import("@chakra-ui/styled-system").ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5">> | undefined>;
        default: string;
    };
    direction: PropType<StackDirection | undefined>;
    divider: PropType<boolean | Component<any, any, any, import("vue").ComputedOptions, import("vue").MethodOptions> | undefined>;
    shouldWrapChildren: PropType<boolean | undefined>;
    isInline: PropType<boolean | undefined>;
}, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, Record<string, any>, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<{
    as: "a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect";
    spacing: import("@chakra-ui/styled-system").ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5">> | undefined;
} & {
    direction?: StackDirection | undefined;
    justify?: import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.JustifyContent> | undefined;
    wrap?: import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.FlexWrap> | undefined;
    divider?: boolean | Component<any, any, any, import("vue").ComputedOptions, import("vue").MethodOptions> | undefined;
    align?: import("@chakra-ui/styled-system").ResponsiveValue<import("csstype").Property.AlignItems> | undefined;
    shouldWrapChildren?: boolean | undefined;
    isInline?: boolean | undefined;
}>, {
    as: "a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect";
    spacing: import("@chakra-ui/styled-system").ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5">> | undefined;
}>;
export {};
